marktools.apply_articulations_to_notes_and_chords_in_expr
=========================================================

.. autofunction:: abjad.tools.marktools.apply_articulations_to_notes_and_chords_in_expr
